# SHOPPING

Tento balíček obsahuje procedury pro vytěžování nákupních portálů.
Umožňuje získávát a analyzovat obchodní/interní informace poblikované na inzertních a nákupních portálech a v sociálních
sítích.
Tyto informace jsou následně obohaceny o územně identifikační údaje a analyticky zpracovány nad prohledávacím strojem
elasticseach.

## Požadavky

Python 3.9+

## Instalace a použití
### pip install sysnet-shopping

(pokud potřebujete ke spuštění  `pip` with oprávnění rool: `sudo pip install sysnet-shopping`)

Pak importujte balíček:

```python
import shopping
```

### Setuptools

Instalace via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user sysnet-shopping
```
(nebo `sudo python setup.py install sysnet-shopping` pro instalaci balíčku pro všechny uživatele)

A import balíčku:

```python
import shopping
```
